Module arch

Contains content related to the CPU instruction set

Structs

Elf32Sym
ElfPhdr
ElfRel
ElfRela
ElfRelr
ElfSymbol

Constants

DT_RELR
This element is similar to DT_RELA, except its table has implicit addends and info, such as Elf32_Relr for the 32-bit file class or Elf64_Relr for the 64-bit file class. If this element is present, the dynamic structure must also have DT_RELRSZ and DT_RELRENT elements.
DT_RELRENT
This element holds the size, in bytes, of the DT_RELR relocation entry.
DT_RELRSZ
This element holds the total size, in bytes, of the DT_RELR relocation table.
EM_ARCH
REL_COPY
REL_DTPMOD
REL_DTPOFF
REL_GOT
REL_IRELATIVE
REL_JUMP_SLOT
REL_NONE
REL_RELATIVE
REL_SYMBOLIC
REL_TPOFF
TLS_DTV_OFFSET

Type Aliases

Dyn
ElfRelType