SymbolTableView

Struct SymbolTableView 

pub struct SymbolTableView<'symtab, L: ElfLayout = NativeElfLayout, H = HashTable<L>> { /* private fields */ }
Read-only symbol table view shared by dynamic and relocatable symbol tables.

Implementations

Source

impl<'symtab, L: ElfLayout, H> SymbolTableView<'symtab, L, H>

pub fn symbols(&self) -> &'symtab [ElfSymbol<L>]

Returns all symbol table entries.

pub fn symbol_idx(&self, idx: usize) -> SymbolEntry<'symtab, L>

Returns the symbol table entry for the given index.

Source

impl<'symtab, L: ElfLayout> SymbolTableView<'symtab, L>

pub fn lookup_by_name( &self, name: impl AsRef<str>, ) -> Option<&'symtab ElfSymbol<L>>

Looks up a symbol by its name.

pub fn count_syms(&self) -> usize

Returns the number of symbols in the symbol table.