Struct ElfDylib

pub struct ElfDylib { /* private fields */ }
An unrelocated dynamic library

Implementations

Source

impl ElfDylib

pub fn easy_relocate<'iter, 'scope, 'find, 'lib, S, F>( self, scope: S, pre_find: &'find F, ) -> Result<RelocatedDylib<'lib>>
where S: Iterator<Item = &'iter RelocatedDylib<'scope>> + Clone, F: Fn(&str) -> Option<*const ()>, 'scope: 'iter, 'iter: 'lib, 'find: 'lib,

Relocate the dynamic library with the given dynamic libraries and function closure.

Note

During relocation, the symbol is first searched in the function closure pre_find.

pub fn relocate<'iter, 'scope, 'find, 'lib, S, F, D>( self, scope: S, pre_find: &'find F, deal_unknown: D, local_lazy_scope: Option<Box<dyn for<'a> Fn(&'a str) -> Option<*const ()> + 'static>>, ) -> Result<RelocatedDylib<'lib>>
where S: Iterator<Item = &'iter RelocatedDylib<'scope>> + Clone, F: Fn(&str) -> Option<*const ()>, D: Fn(&ElfRela, &ElfDylib, S) -> bool, 'scope: 'iter, 'iter: 'lib, 'find: 'lib,

Relocate the dynamic library with the given dynamic libraries and function closure.

Note
  • During relocation, the symbol is first searched in the function closure pre_find.
  • The deal_unknown function is used to handle relocation types not implemented by efl_loader or failed relocations
  • Typically, the scope should also contain the current dynamic library itself, relocation will be done in the exact order in which the dynamic libraries appear in scope.
  • When lazy binding, the symbol is first looked for in the global scope and then in the local lazy scope
Source

impl ElfDylib

pub fn entry(&self) -> usize

Gets the entry point of the elf object.

pub fn core_component_ref(&self) -> &CoreComponent

Gets the core component reference of the elf object

pub fn core_component(&self) -> CoreComponent

Gets the core component of the elf object

pub fn user_data_mut(&mut self) -> Option<&mut UserData>

Gets mutable user data from the elf object.

pub fn is_lazy(&self) -> bool

Whether lazy binding is enabled for the current dynamic library.

pub fn rpath(&self) -> Option<&str>

Gets the DT_RPATH value.

pub fn runpath(&self) -> Option<&str>

Gets the DT_RUNPATH value.

Methods from Deref<Target = CoreComponent>

pub fn downgrade(&self) -> CoreComponentRef

Creates a new Weak pointer to this allocation.

pub fn user_data(&self) -> &UserData

Gets user data from the elf object.

pub fn strong_count(&self) -> usize

Gets the number of strong references to the elf object.

pub fn weak_count(&self) -> usize

Gets the number of weak references to the elf object.

pub fn name(&self) -> &str

Gets the name of the elf object.

pub fn cname(&self) -> &CStr

Gets the C-style name of the elf object.

pub fn shortname(&self) -> &str

Gets the short name of the elf object.

pub fn base(&self) -> usize

Gets the base address of the elf object.

pub fn map_len(&self) -> usize

Gets the memory length of the elf object map.

pub fn phdrs(&self) -> &[Phdr]

Gets the program headers of the elf object.

pub fn dynamic(&self) -> *const Dyn

Gets the address of the dynamic section.

pub fn needed_libs(&self) -> &[&'static str]

Gets the needed libs’ name of the elf object.

pub fn symtab(&self) -> &SymbolTable

Gets the symbol table.