Struct Loader

pub struct Loader<M>
where M: Mmap,
{ /* private fields */ }
The elf object loader

Implementations

Source

impl<M: Mmap> Loader<M>

pub fn easy_load_dylib(&mut self, object: impl ElfObject) -> Result<ElfDylib>

Load a dynamic library into memory

pub fn load_dylib( &mut self, object: impl ElfObject, lazy_bind: Option<bool>, ) -> Result<ElfDylib>

Load a dynamic library into memory

Note

When lazy_bind is not set, lazy binding is enabled using the dynamic library’s DT_FLAGS flag.

pub async fn load_dylib_async( &mut self, object: impl ElfObjectAsync, lazy_bind: Option<bool>, ) -> Result<ElfDylib>

Load a dynamic library into memory

Note

When lazy_bind is not set, lazy binding is enabled using the dynamic library’s DT_FLAGS flag.

Source

impl<M: Mmap> Loader<M>

pub fn easy_load_exec(&mut self, object: impl ElfObject) -> Result<ElfExec>

Load a executable file into memory

pub fn load_exec( &mut self, object: impl ElfObject, lazy_bind: Option<bool>, ) -> Result<ElfExec>

Load a executable file into memory

Note
  • When lazy_bind is not set, lazy binding is enabled using the dynamic library’s DT_FLAGS flag.
pub async fn load_exec_async( &mut self, object: impl ElfObjectAsync, lazy_bind: Option<bool>, ) -> Result<ElfExec>

Load a executable file into memory

Note
  • When lazy_bind is not set, lazy binding is enabled using the dynamic library’s DT_FLAGS flag.
Source

impl<M: Mmap> Loader<M>

pub fn easy_load(&mut self, object: impl ElfObject) -> Result<Elf>

Load a elf file into memory

pub fn load( &mut self, object: impl ElfObject, lazy_bind: Option<bool>, ) -> Result<Elf>

Load a elf file into memory

Note
  • When lazy_bind is not set, lazy binding is enabled using the dynamic library’s DT_FLAGS flag.
pub async fn load_async( &mut self, object: impl ElfObjectAsync, lazy_bind: Option<bool>, ) -> Result<Elf>

Load a elf file into memory

Note
  • When lazy_bind is not set, lazy binding is enabled using the dynamic library’s DT_FLAGS flag.
Source

impl<M: Mmap> Loader<M>

pub fn new() -> Self

Create a new loader

pub fn set_init_params( &mut self, argc: usize, argv: usize, envp: usize, ) -> &mut Self

glibc passes argc, argv, and envp to functions in .init_array, as a non-standard extension.

pub fn set_hook( &mut self, hook: Box<dyn Fn(&CStr, &ElfPhdr, &ElfSegments, &mut UserData) -> Result<(), Box<dyn Any + Send + Sync>>>, ) -> &mut Self

hook functions are called first when a program header is processed

pub fn read_ehdr(&mut self, object: &mut impl ElfObject) -> Result<ElfHeader>

Read the elf header

pub fn read_phdr( &mut self, object: &mut impl ElfObject, ehdr: &ElfHeader, ) -> Result<&[ElfPhdr]>

Read the program header table