Contains content related to the CPU instruction set
Structs
Constants
- DT_RELR
- This element is similar to DT_RELA, except its table has implicit addends and info, such as Elf32_Relr for the 32-bit file class or Elf64_Relr for the 64-bit file class. If this element is present, the dynamic structure must also have DT_RELRSZ and DT_RELRENT elements.
- DT_
RELRENT - This element holds the size, in bytes, of the DT_RELR relocation entry.
- DT_
RELRSZ - This element holds the total size, in bytes, of the DT_RELR relocation table.
- EM_ARCH
- REL_
COPY - REL_
DTPMOD - REL_
DTPOFF - REL_GOT
- REL_
IRELATIVE - REL_
JUMP_ SLOT - REL_
NONE - REL_
RELATIVE - REL_
SYMBOLIC - REL_
TPOFF - TLS_
DTV_ OFFSET