pub struct ElfDylib { /* private fields */ }Expand description
An unrelocated dynamic library
Implementations
Sourceimpl ElfDylib
impl ElfDylib
Sourcepub fn easy_relocate<'iter, 'scope, 'find, 'lib, S, F>(
self,
scope: S,
pre_find: &'find F,
) -> Result<RelocatedDylib<'lib>>
pub fn easy_relocate<'iter, 'scope, 'find, 'lib, S, F>( self, scope: S, pre_find: &'find F, ) -> Result<RelocatedDylib<'lib>>
Relocate the dynamic library with the given dynamic libraries and function closure.
Note
During relocation, the symbol is first searched in the function closure pre_find.
Sourcepub fn relocate<'iter, 'scope, 'find, 'lib, S, F, D>(
self,
scope: S,
pre_find: &'find F,
deal_unknown: D,
local_lazy_scope: Option<Box<dyn for<'a> Fn(&'a str) -> Option<*const ()> + 'static>>,
) -> Result<RelocatedDylib<'lib>>
pub fn relocate<'iter, 'scope, 'find, 'lib, S, F, D>( self, scope: S, pre_find: &'find F, deal_unknown: D, local_lazy_scope: Option<Box<dyn for<'a> Fn(&'a str) -> Option<*const ()> + 'static>>, ) -> Result<RelocatedDylib<'lib>>
Relocate the dynamic library with the given dynamic libraries and function closure.
Note
- During relocation, the symbol is first searched in the function closure
pre_find. - The
deal_unknownfunction is used to handle relocation types not implemented by efl_loader or failed relocations - Typically, the
scopeshould also contain the current dynamic library itself, relocation will be done in the exact order in which the dynamic libraries appear inscope. - When lazy binding, the symbol is first looked for in the global scope and then in the local lazy scope
Sourceimpl ElfDylib
impl ElfDylib
Sourcepub fn core_component_ref(&self) -> &CoreComponent
pub fn core_component_ref(&self) -> &CoreComponent
Gets the core component reference of the elf object
Sourcepub fn core_component(&self) -> CoreComponent
pub fn core_component(&self) -> CoreComponent
Gets the core component of the elf object
Sourcepub fn user_data_mut(&mut self) -> Option<&mut UserData>
pub fn user_data_mut(&mut self) -> Option<&mut UserData>
Gets mutable user data from the elf object.
Methods from Deref<Target = CoreComponent>
Sourcepub fn downgrade(&self) -> CoreComponentRef
pub fn downgrade(&self) -> CoreComponentRef
Creates a new Weak pointer to this allocation.
Sourcepub fn strong_count(&self) -> usize
pub fn strong_count(&self) -> usize
Gets the number of strong references to the elf object.
Sourcepub fn weak_count(&self) -> usize
pub fn weak_count(&self) -> usize
Gets the number of weak references to the elf object.
Sourcepub fn needed_libs(&self) -> &[&'static str]
pub fn needed_libs(&self) -> &[&'static str]
Gets the needed libs’ name of the elf object.