elf_loader

Struct ElfDylib

pub struct ElfDylib { /* private fields */ }
An unrelocated dynamic library

Implementations

Source

impl ElfDylib

pub fn relocate<'scope, S, F, D>( self, scope: S, find: &'scope F, deal_unknown: D, lazy_scope: Option<Box<dyn for<'a> Fn(&'a str) -> Option<*const ()> + 'static>>, ) -> Result<RelocatedDylib<'scope>>
where S: Iterator<Item = &'scope CoreComponent> + Clone, F: Fn(&str) -> Option<*const ()>, D: Fn(&ElfRela, &ElfDylib, S) -> bool,

Relocate the dynamic library with the given dynamic libraries and function closure.

Note
  • During relocation, it is preferred to look for symbols in function closures find.
  • The deal_unknown function is used to handle relocation types not implemented by efl_loader or failed relocations
  • Typically, the scope should also contain the current dynamic library itself, relocation will be done in the exact order in which the dynamic libraries appear in scope.
  • When lazy binding, the symbol is first looked for in the global scope and then in the lazy scope
Source

impl ElfDylib

pub fn entry(&self) -> usize

Gets the entry point of the elf object.

pub fn phdrs(&self) -> &[Phdr]

Gets phdrs of the elf object.

pub fn cname(&self) -> &CStr

Gets the C-style name of the elf object.

pub fn name(&self) -> &str

Gets the name of the elf object.

pub fn dynamic(&self) -> *const Dyn

Gets the address of the dynamic section.

pub fn base(&self) -> usize

Gets the base address of the elf object.

pub fn map_len(&self) -> usize

Gets the memory length of the elf object map.

pub fn symtab(&self) -> &SymbolTable

Gets the symbol table.

pub fn dyn_relocation(&self) -> Option<&[ElfRela]>

Gets rela.dyn section content

pub fn plt_relocation(&self) -> Option<&[ElfRela]>

Gets rela.plt section content

pub unsafe fn core_component_ref(&self) -> &CoreComponent

Gets the core component reference of the elf object

Safety

The current elf object has not yet been relocated, so it is dangerous to use this function to get CoreComponent in the elf object.

pub unsafe fn core_component(&self) -> CoreComponent

Gets the core component of the elf object

Safety

The current elf object has not yet been relocated, so it is dangerous to use this function to get CoreComponent in the elf object.

pub fn needed_libs(&self) -> &[&'static str]

Gets the name of the elf object

pub fn user_data(&self) -> &UserData

Gets user data from the elf object.

pub fn is_lazy(&self) -> bool

Whether lazy binding is enabled for the current dynamic library.

pub fn rpath(&self) -> Option<&str>

Gets the DT_RPATH value.

pub fn runpath(&self) -> Option<&str>

Gets the DT_RUNPATH value.